@@ -149,7 +149,7 @@ class Model():
         elif problem == 'scp':
             # Read SCP benchmark instance
             self.sense = GRB.MINIMIZE
-            self.m, n = [int(item) for item in lines.pop(0).split()]
+            self.m, _ = [int(item) for item in lines.pop(0).split()]
             for j in range(n):
                 self.c_low[j], self.c_upp[j] = [int(item) for item in lines.pop(0).split()]
             self.a = {(i,j): 0 for i in range(self.m) for j in range(n)}
@@ -166,7 +166,7 @@ class Model():
                 self.sense = GRB.MINIMIZE
             elif sense == 'MAX':
                 self.sense = GRB.MAXIMIZE
-            self.m = int(lines.pop(0))
+            self.m, _ = [int(item) for item in lines.pop(0).split()]
             for j,v in enumerate(lines.pop(0).split()):
                 self.c_low[j] = int(v)
             for j,v in enumerate(lines.pop(0).split()):
@@ -177,15 +177,16 @@ class Model():
             for i,v in enumerate(lines.pop(0).split()):
                 self.b[i] = int(v)
     
-    def solve(self, algorithm: str = 'ids-b', timelimit: int = 3600):
+    def solve(self, algorithm: str = 'fix', timelimit: int = 30):
         """Solve the problem
 
         Args:
-            algorithm (str): algorithm name. Defaults ids-b.
-            timelimit (int, optional): time limit. Defaults 3600.
+            algorithm (str): algorithm name. Defaults fix.
+            timelimit (int, optional): time limit. Defaults 30.
         """
         if algorithm not in {'fix', 'bc', 'ds', 'ids-h', 'ids-b'}:
             raise Exception("Algorithm type is not correct")
+        self.algorithm = algorithm
         # Set time limit
         self.timelimit = timelimit
         # Set start time
